@@ -24,7 +24,7 @@ def configure_gallerydl(vparams: VParams, dest: str):
     gallery_dl.config.set(("downloader", "http",), "timeout", timeout)
 
     # Set download path
-    gallery_dl.config.set((), "extractor", {"base-directory": os.path.abspath(dest)})
+    gallery_dl.config.set((), "extractor", {"base-directory": dest})
 
     # Mute internal logs
     gallery_dl.config.set(("output",), "mode", "null")
@@ -64,7 +64,11 @@ def get_images_from_gallery(gallery_url):
 
 def download_single_image(url, target_path):
     dlj = DownloadJob(url)
-    dlj.extractor.directory_fmt = tuple(os.path.dirname(target_path).split(os.path.sep))
+
+    base_dir = gallery_dl.config.get((), "extractor")["base-directory"]
+    target_path_rel = target_path.lstrip(base_dir)
+
+    dlj.extractor.directory_fmt = tuple(os.path.dirname(target_path_rel).split(os.path.sep))
     dlj.extractor.filename_fmt = "{filename}.{extension}"
     dlj.run()
 
